# Thea

***"Titaness of (...) the shining light of the clear blue sky"**
from [Wikipedia](https://en.wikipedia.org/wiki/Thea) retrieved 1 November 2018.*

---

[![Python version](https://img.shields.io/badge/python-3.6%20%7C%203.7-blue.svg)](https://www.python.org/downloads/)
[![Linux status](https://img.shields.io/travis/com/mikevansighem/thea/master.svg?label=linux)](https://travis-ci.com/mikevansighem/thea)
[![Windows status](https://img.shields.io/appveyor/ci/mikevansighem/thea/master.svg?label=windows)](https://ci.appveyor.com/project/mikevansighem/thea/branch/master)
[![Docs](https://img.shields.io/website-up-down-green-red/http/shields.io.svg?label=docs)](https://mikevansighem.github.io/thea/)
[![Codacy Badge](https://img.shields.io/codacy/grade/bb3d838b073c489b89232463f0c2cf66.svg)](https://www.codacy.com/app/mikevansighem/thea?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mikevansighem/thea&amp;utm_campaign=Badge_Grade)
[![Codacy Badge](https://img.shields.io/codacy/coverage/bb3d838b073c489b89232463f0c2cf66.svg)](https://www.codacy.com/app/mikevansighem/thea?utm_source=github.com&utm_medium=referral&utm_content=mikevansighem/thea&utm_campaign=Badge_Coverage)
[![Updates](https://pyup.io/repos/github/mikevansighem/thea/shield.svg)](https://pyup.io/repos/github/mikevansighem/thea/)
[![License: LGPL 3](https://img.shields.io/badge/license-LGPL%203-blue.svg)](LICENSE.md)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

---

Thea is used to control the environment of model (train) layouts based
on real-world data and simulation models. Current development is focused
around lighting 🌄 but we plan to expand the functionalities to include
sound 🔉 and actuator control.

---

![](docs/images/header.png)

---

## 🌱 Origin

This project was started in order to control lighting of model-train
layouts in more interesting ways. Most solutions only offer manual
and rule based control resulting in very predictive behavior. Thea
breaks with this by controlling the model environment based on real-word
data and simulation models that introduce an element of randomness.

## ✅ Principles

-   Science based environment simulation;
-   Simple to start but complex if you want to;
-   Modern user interface;
-   Support for common hardware;

## ✨ Features

Currently Thea is in early development so the list of available features
is a bit short. However we have a lot planned:

-   [x] Accelerated model time
-   [ ] Day and night cycle 🌓
-   [ ] Hardware control over MQTT
-   [ ] Household lighting
-   [ ] Weather patterns 🌀
-   [ ] Traffic 🚗
-   [ ] Opening-hours 🕓
-   [ ] Graphical user interface
-   [ ] Moon and stars 🌛✨
-   [ ] DCC train control 🚂
-   [ ] Weather sounds 🔉

## 🤔 Getting started

Currently there is not much use in this project as an end user. However
if you would like to contribute head over to the
[contributing](https://mikevansighem.github.io/thea/contibuting) section
of our documentation. We are happy to receive pull-requests.

## 📚 Documentation

All our documentation including on how to get started can be found
[here](https://mikevansighem.github.io/thea).

## 📃 License

Thea is created by Mike van Sighem and licensed under LGPL version 3.
Refer to the
[license](https://github.com/mikevansighem/thea/blob/master/docs/LICENSE.md)
for more details.

## 💛 Contributing 

We are happy to see contributors on the project. Head over to the
[contributing](https://mikevansighem.github.io/thea/contibuting) section
of our documentation and submit your first pull-requests.
